src/eric7/CycloneDXInterface/CycloneDXConfigDialog.py

branch
eric7
changeset 9509
c06561080e32
parent 9413
80c06d472826
child 9653
e67609152c5e
--- a/src/eric7/CycloneDXInterface/CycloneDXConfigDialog.py	Sat Nov 12 17:49:08 2022 +0100
+++ b/src/eric7/CycloneDXInterface/CycloneDXConfigDialog.py	Sun Nov 13 14:10:57 2022 +0100
@@ -189,9 +189,9 @@
         @return tuple containing the input source, the input file name, the
             file format, the schema version, the path of the SBOM file to be
             written, a flag indicating to include vulnerability information,
-            a flag indicating to include dependency information and a
-            dictionary containing the SBOM meta data
-        @rtype tuple of (str, str, str, str, str, bool, bool, dict)
+            a flag indicating to include dependency information, a flag indicating
+            to generate readable output and a dictionary containing the SBOM meta data
+        @rtype tuple of (str, str, str, str, str, bool, bool, bool, dict)
         """
         if self.environmentButton.isChecked():
             inputSource = "environment"
@@ -237,5 +237,6 @@
             sbomFile,
             self.vulnerabilityCheckBox.isChecked(),
             self.dependenciesCheckBox.isChecked(),
+            self.readableCheckBox.isChecked(),
             self.__metadata,
         )

eric ide

mercurial